Izvedba ocene tveganja z orodjem OiRA | OiRA

Teme

# Izvedba ocene tveganja z orodjem OiRA

## Začetek nove seje

Za začetek nove seje kliknite povezavo ,začni novo sejo‘.

## Odpiranje ocene tveganja

Ko začnete postopek izvedbe ocene tveganja, jo lahko kadar koli znova odprete v oddelku ,Moje ocene tveganja‘ na strani s pregledom. V tem oddelku lahko tudi začnete novo oceno tveganja.

Pregled.

## Krmarjenje po oceni tveganja

Vsaka ocena tveganja vas vodi po več korakih. Prikazani so v glavnem meniju na levi strani zaslona:

- Priprava
- Vključenost
- Identifikacija + Ocena
- Načrt ukrepov
- Poročilo
- Status

Struktura posameznega orodja je lahko različna in je odvisna od odločitev naših partnerjev/razvijalcev orodja OiRA. V nekaterih orodjih korak identifikacije in ocene tveganja vključuje načrt ukrepov. V tem primeru je na levi strani zaslona prikazan naslednji meni:

- Priprava
- Vključenost
- Ocena
- Poročilo
- Status

## Priprava

Vsako sejo/orodje začnete s korakom ,Priprava‘. V tem koraku poimenujete oceno tveganja, da jo boste pozneje lažje našli med več različnimi ocenami tveganja, ki jih boste izvedli z orodjem.

Če kliknete povezavo ,Preberite več o tem orodju…‘, lahko preberete dodatne informacije o izbranem orodju in straneh, ki so sodelovale pri njegovem razvoju.

Ko kliknete gumb ,Začni‘, vam bodo morda zastavljena nekatera dodatna vprašanja, odvisno od orodja, ki ga uporabljate. Ta zaslon z ,vprašanji o profilu‘ v koraku priprave se prikaže samo v orodjih, ki ponujajo to možnost.

Na tem zaslonu lahko:

- izberete ali preskočite okoliščine, glede na to, ali se nanašajo na vašo poslovno dejavnost. Kadar je to ustrezno, izberite ,da‘;
- navedete več poslovnih enot, podružnic ali trgovin in podobno. Ob vsakem vnosu se tveganja ponovno prikažejo.

Zaslon ,Profil‘ v koraku priprava

Korak priprave je zelo pomemben, saj v njem točno opredelite vrsto poslovne dejavnosti in povezana tveganja, s katerimi se srečuje vaše podjetje. Ko kliknete ,Shrani in naprej‘, se premaknete na naslednji oddelek ,Vključenost‘.

Opomba: Mnogo orodij ne vključuje vprašanj o profilu, saj ne uporabljajo te funkcije za ciljno usmerjanje orodja. V tem primeru se ta zaslon samodejno preskoči.

## Vključenost

Ta korak vas opominja, kako pomembno je vključiti delavce, in ponuja različne načine za zagotovitev dobre vključenosti delavcev. V tem koraku lahko prenesete ali natisnete vsebino ocene tveganja, da z njo seznanite svoje delavce/zaposlene. Tako zagotovite, da lahko delavci prispevajo k nalogi ocenjevanja okoliščin na delovnem mestu.

## Ocena

V tem koraku opredelite nevarnosti in težave, ki se nanašajo na vaše podjetje.

Opomba: Glede na to, kako je partner orodja OiRA konfiguriral orodje, je morda v ta zaslon vključen tudi korak ,Načrt ukrepov‘ (glej spodaj). V tem primeru se celotni korak imenuje ,Ocena‘, elementi, opisani v koraku ,Načrt ukrepov‘, pa so prikazani v identifikaciji in oceni vsakega tveganja.

Identifikacija in ocena.

Pod oddelkom ,Identifikacija + Ocena‘ na levi strani zaslona lahko vidite posamezne teme/module, vključene v orodje. Tema, ki si jo trenutno ogledujete, je poudarjena.

## Identifikacija

Pri vsakem tveganju se morate odločiti, ali se izjava, ki opisuje želeno stanje, nanaša na vaše podjetje. Odgovorite lahko z:

- da: če na izjavo odgovorite z ,da‘, nadaljnji ukrepi niso potrebni, saj ste ocenili, da tveganje ni prisotno;
- ne: če na izjavo odgovorite z ,ne‘, je treba sprejeti nadaljnje ukrepe. Pozvani ste, da se odločite, katere specifične ukrepe boste sprejeli;
- ni smiselno: pri nekaterih izjavah o tveganju je na voljo možnost ,ni smiselno‘, kar pomeni, da se tveganje ne nanaša na vaše podjetje/poslovno enoto.

Pod vsako izjavo je običajno več informacij o specifičnem tveganju:

- informacije: kratek opis, ki je včasih dopolnjen s slikami, z več podrobnostmi o tveganju;
- viri: dodatne informacije o tveganju, kot so zakonodaja in drugi viri. Včasih so v tem oddelku priloženi tudi dokumenti za dodatno literaturo;
- opombe: v ta oddelek lahko vnesete svoje opombe, ki bodo ob koncu ocene prikazane v poročilu.

Ko odgovorite na izjavo o tveganju in nadaljujete na naslednji korak, se meni na levi strani zaslona posodobi z barvnim simbolom, ki označuje, ali ste:

- odgovorili z ,da‘ (zelena kljukica);
- odgovorili z ,ne‘“ (rdeč križec);
- preložili odgovor (oranžen vprašaj).

Pri neodgovorjenih vprašanjih ostane prikazan siv simbol.

### Ocena

V tem koraku ocenite prioriteto tveganja, ki ste ga opredelili.

Ocena tveganja.

Opomba: V nekaterih orodjih OiRA ocena ni prikazana. To je odvisno od tega, kako je nacionalni partner/razvijalec orodja OiRA konfiguriral posamezno orodje OiRA.

Če ste opredelili, da je tveganje prisotno (označeno z rdečim križcem), se prikaže oddelek za oceno. Glede na metodo ocenjevanja, ki je določena za posamezno tveganje, ste pozvani, da:

ocenite prioriteto: nizka, srednja ali visoka.

Določanje prioritete tveganja.

ALI

- odgovorite na nekaj vprašanj o pogostosti, resnosti in verjetnosti tveganja, da se lahko prioriteta izračuna na podlagi vaših odgovorov.

Določanje spremenljivk tveganja.

### Prednostna tveganja, določena za posamezne sektorje:

Nacionalni partner/razvijalec orodja, ki je ustvaril specifično orodje OiRA, je nekatera tveganja obravnaval kot zelo pomembna. Takih ,prednostnih tveganj‘ vam ni treba oceniti, saj se samodejno označijo z ,visoko‘ prednostnostjo.

Prednostna tveganja.

### Dodatna tveganja

Ko odgovorite na vse teme, povezane s tveganjem, v oddelku ,Identifikacija + Ocena‘, se premaknete na izbirno temo ,Vaša dodatna tveganja‘. V tem oddelku lahko s klikom gumba ,Dodaj tveganje‘ vnesete svoja tveganja.

Če v orodju ni tveganj, ki so prisotna na vašem delovnem mestu/v vašem podjetju, jih morate dodati tukaj. Ta tveganja lahko v celoti opredelite/opišete sami.

Dodatna tveganja.

Oddelek ,Dodatna tveganja‘ je zelo podoben oddelkom z drugimi tveganji v orodju OiRA, seveda pa morate vnesti svoje besedilo. To besedilo mora vključevati vsaj kratko izjavo o težavnih okoliščinah, navedete pa lahko tudi daljši opis. Za opis določene okoliščine lahko naložite tudi sliko.

Tako kot pri drugih tveganjih morate navesti, ali je tveganje prisotno ali ne. Ko ta dodatna tveganja uspešno odpravite, jih lahko označite kot urejena, hkrati pa jih vključite v svojo oceno tveganja za namene dokumentiranja.

Dodate lahko poljubno število tveganj.

Dodaj dodatno tveganje.

## Načrt ukrepov

V tem koraku se odločite, katere ukrepe boste sprejeli, da odpravite ali zmanjšate tveganja, ki ste jih predhodno opredelili.

Opomba: Kot je bilo navedeno zgoraj, je načrt ukrepov prikazan kot ločen korak v meniju na levi strani zaslona ali pri vsakem opredeljenem tveganju. Če je prikazan pri posameznih tveganjih, se korak v meniju imenuje ,Ocena‘, zajema pa izjave o tveganju in razpoložljive odgovore.

Različica tega koraka, ki je prikazana v vašem orodju, je odvisna od odločitev nacionalnih partnerjev/razvijalcev orodja OiRA.

### Vključen načrt ukrepov

Vključen načrt ukrepov.

Če odgovorite z ,ne‘, se modul načrta ukrepov prikaže na strani pod naslovom ,Ukrepi‘.

Izberete lahko ukrep s seznama ukrepov, ki jih predlaga sistem, ali določite svoje ukrepe.

### Ločen načrt ukrepov

Kadar je načrt ukrepov ločen korak, bo na voljo prek navigacije na levi strani zaslona.

Kliknite gumb ,Ustvari načrt ukrepov‘, da začnete svoj načrt.

V koraku ,Načrt ukrepov‘ so zdaj v meniju na levi strani zaslona prikazana samo tveganja, za katera je bilo označeno, da je treba sprejeti nadaljnje ukrepe, saj je bilo za druga tveganja označeno, da niso prisotna.

Pozvani boste k opredelitvi ukrepov za vsako tveganje, za katero ste se med postopkom ocenjevanja odločili, da ni prisotno, in za vsako prednostno tveganje (ne glede na to, ali ste na izjavo, povezano s tem tveganjem, odgovorili z ,da‘ ali ,ne‘).

Tveganje v načrtu ukrepov.

Izberete lahko ukrep s seznama ukrepov, ki jih predlaga sistem, ali določite svoje ukrepe.

#### Dodajte svoj ukrep

Dodajanje ukrepa.

Za začetek določanja varnostnega ukrepa kliknite gumb ,Vaš dodan ukrep‘. Narediti morate naslednje:

- opisati splošni pristop za odpravo ali zmanjšanje tveganja;
- po želji navesti raven potrebne strokovnosti in/ali zahteve (npr. tukaj lahko dodate opis, če je za obravnavanje tega tveganja potrebno posebno usposabljanje ali zunanje strokovno znanje);
- navesti, kdo je odgovoren za izvedbo;
- navesti potrebna sredstva, kadar je to ustrezno;
- po želji določiti datume, kdaj naj bi se ukrep začel izvajati in kdaj načrtujete zaključek izvajanja ukrepa.

Dodate lahko poljubno število tveganj.

#### Dodajte splošne ukrepe

Glede na to, kako je partner/razvijalec orodja OiRA konfiguriral orodje, so za posamezna tveganja na voljo vnaprej opredeljeni ukrepi. Če želite izbrati enega od vnaprej opredeljenih ukrepov, kliknite gumb ,Izberite ukrep(e)‘.

Odpre se pojavno okno, v katerem so prikazani vsi predlagani ukrepi. Kliknite gumb ,Dodaj‘ za ukrepe, ki jih želite uporabiti.

Ti vnaprej opredeljeni ukrepi so nato prikazani v vašem načrtu ukrepov. Opis, kaj je treba storiti, je že vnesen, druga polja (kdo odgovoren, potrebna sredstva, datumi) pa lahko in morate izpolniti sami.

Dodajanje standardnih ukrepov.

Kadar koli lahko zbrišete tako splošne kot svoje ukrepe.

## Poročilo

Ko končate načrt ukrepov, lahko pripravite poročilo.

V tem koraku lahko vnesete besedilo, če želite v poročilo vključiti morebitne pripombe.

Komentiraj poročilo.

Če želite prebrati več o različnih poročilih in načinih njihove uporabe, obiščite to stran.

## Status

Majhen tortni grafikon v meniju na levi strani zaslona prikazuje vaš napredek v orodju.

Oddelek s statusom zagotavlja pregled nad tem, koliko tveganj ste opredelili, koliko ste jih obravnavali s sprejetjem ukrepov in na koliko izjav o tveganjih še morate odgovoriti.

Stran s statusom.

Ko se premaknete na zaslon s statusom, si lahko ogledate svoj napredek v posameznih modulih. Tako lahko ugotovite, katera tveganja še morate oceniti ali katere ukrepe še morate sprejeti za tveganja, ki ste jih opredelili.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More